@@ -17,6 +17,8 @@ package columns
 import (
 	"testing"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/columns/ellipsis"
 )
 
@@ -24,17 +26,11 @@ func TestOptions(t *testing.T) {
 	opts := GetDefault()
 
 	WithAlignment(AlignRight)(opts)
-	if opts.DefaultAlignment != AlignRight {
-		t.Errorf("Expected default alignment to be AlignRight")
-	}
+	require.Equal(t, AlignRight, opts.DefaultAlignment)
 
 	WithEllipsis(ellipsis.Middle)(opts)
-	if opts.DefaultEllipsis != ellipsis.Middle {
-		t.Errorf("Expected ellipsis to be ellipsis.Middle")
-	}
+	require.Equal(t, ellipsis.Middle, opts.DefaultEllipsis)
 
 	WithWidth(2342)(opts)
-	if opts.DefaultWidth != 2342 {
-		t.Errorf("Expected default width to be 2342")
-	}
+	require.Equal(t, 2342, opts.DefaultWidth)
 }
